@@ -115,6 +115,50 @@ class TestHTML:
         m = p.search(html)
         assert float(m.group(1)) >= sleep
 
+    @pytest.mark.parametrize(
+        "duration_formatter,expected_report_content",
+        [
+            ("%f", r'<td class="col-duration">\d{2}</td>'),
+            ("%S.%f", r'<td class="col-duration">\d{2}\.\d{2}</td>'),
+            (
+                "ABC%H  %M %S123",
+                r'<td class="col-duration">ABC\d{2}  \d{2} \d{2}123</td>',
+            ),
+        ],
+    )
+    def test_can_format_duration_column(
+        self, testdir, duration_formatter, expected_report_content
+    ):
+
+        testdir.makeconftest(
+            f"""
+            import pytest
+
+            @pytest.hookimpl(hookwrapper=True)
+            def pytest_runtest_makereport(item, call):
+                outcome = yield
+                report = outcome.get_result()
+                setattr(report, "duration_formatter", "{duration_formatter}")
+        """
+        )
+
+        sleep = float(0.2)
+        testdir.makepyfile(
+            """
+            import time
+            def test_sleep():
+                time.sleep({:f})
+        """.format(
+                sleep
+            )
+        )
+        result, html = run(testdir)
+        assert result.ret == 0
+        assert_results(html, duration=sleep)
+
+        compiled_regex = re.compile(expected_report_content)
+        assert compiled_regex.search(html)
+
     def test_pass(self, testdir):
         testdir.makepyfile("def test_pass(): pass")
         result, html = run(testdir)
@@ -143,17 +187,47 @@ class TestHTML:
         assert "AssertionError" in html
 
     def test_rerun(self, testdir):
+        testdir.makeconftest(
+            """
+            import pytest
+
+            @pytest.hookimpl(hookwrapper=True)
+            def pytest_runtest_makereport(item, call):
+                pytest_html = item.config.pluginmanager.getplugin("html")
+                outcome = yield
+                report = outcome.get_result()
+
+                extra = getattr(report, "extra", [])
+                if report.when == "call":
+                    extra.append(pytest_html.extras.url("http://www.example.com/"))
+                report.extra = extra
+        """
+        )
+
         testdir.makepyfile(
             """
             import pytest
-            @pytest.mark.flaky(reruns=5)
+            import time
+
+            @pytest.mark.flaky(reruns=2)
             def test_example():
+                time.sleep(1)
                 assert False
         """
         )
+
         result, html = run(testdir)
         assert result.ret
-        assert_results(html, passed=0, failed=1, rerun=5)
+        assert_results(html, passed=0, failed=1, rerun=2)
+
+        expected_report_durations = r'<td class="col-duration">1.\d{2}</td>'
+        assert len(re.findall(expected_report_durations, html)) == 3
+
+        expected_report_extras = (
+            r'<td class="col-links"><a class="url" href="http://www.example.com/" '
+            'target="_blank">URL</a> </td>'
+        )
+        assert len(re.findall(expected_report_extras, html)) == 3
 
     def test_no_rerun(self, testdir):
         testdir.makepyfile("def test_pass(): pass")
